/*******************************************************************************
 * Copyright (c) 2004, 2005 IBM Corporation.
 * All rights reserved. 
 *******************************************************************************/
package com.ibm.samplesgallery.servlets;
import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;

import com.ibm.samplegallery.internal.*;

/**
 * Abstract class that handles all toolbars.
 * Details on what buttons to display is retrieved by calling getToolbarData().
 */

public abstract class GalleryAbstractToolbar extends HttpServlet implements GalleryConstants {
	/* (non-Javadoc)
	 * @see javax.servlet.http.HttpServlet#doGet(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
	 */
	protected void doGet(HttpServletRequest arg0, HttpServletResponse arg1)
		throws ServletException, IOException {
		this.processRequest(arg0, arg1);
	}
	
	/* (non-Javadoc)
	 * @see javax.servlet.http.HttpServlet#doPost(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
	 */
	protected void doPost(HttpServletRequest arg0, HttpServletResponse arg1)
		throws ServletException, IOException {
		this.processRequest(arg0, arg1);
	}
	
	protected abstract AbstractToolbarData getToolbarData(HttpServletRequest req, HttpServletResponse resp);
	
	private void processRequest(HttpServletRequest req, HttpServletResponse resp) throws IOException {
		AbstractToolbarData data = this.getToolbarData(req, resp);
		WebappPreferences prefs = data.getPrefs();
		resp.setContentType("text/html;charset=UTF-8"); //$NON-NLS-1$
		StringBuffer html = new StringBuffer();
		html.append("<html>\n"); //$NON-NLS-1$
		html.append("<head>\n"); //$NON-NLS-1$
		html.append("<meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\">\n"); //$NON-NLS-1$
		html.append("<style type=\"text/css\">\n"); //$NON-NLS-1$
		html.append("HTML {\n"); //$NON-NLS-1$
		html.append("margin:0px;\n"); //$NON-NLS-1$
		html.append("padding:0px;\n"); //$NON-NLS-1$
		html.append("}\n"); //$NON-NLS-1$
		html.append("\n"); //$NON-NLS-1$
		html.append("BODY {\n"); //$NON-NLS-1$
		html.append("background:" + prefs.getToolbarBackground() + ";\n"); //$NON-NLS-1$ //$NON-NLS-2$
		html.append("}\n"); //$NON-NLS-1$
		html.append("\n"); //$NON-NLS-1$
		html.append("#titleText {\n"); //$NON-NLS-1$
		html.append("font-weight:bold;\n"); //$NON-NLS-1$
		html.append("}\n"); //$NON-NLS-1$
		html.append("\n"); //$NON-NLS-1$
		html.append(".buttonOn a {\n"); //$NON-NLS-1$
		html.append("display:block;\n"); //$NON-NLS-1$
		html.append("margin-left:2px;\n"); //$NON-NLS-1$
		html.append("margin-right:2px;\n"); //$NON-NLS-1$
		html.append("width:20px;\n"); //$NON-NLS-1$
		html.append("height:20px;\n"); //$NON-NLS-1$
		html.append("border:1px solid Highlight;\n"); //$NON-NLS-1$
		html.append("writing-mode:tb-rl;\n"); //$NON-NLS-1$
		html.append("vertical-align:middle;\n"); //$NON-NLS-1$
		html.append("background: " + prefs.getViewBackground() + ";\n"); //$NON-NLS-1$ //$NON-NLS-2$
		html.append("}\n"); //$NON-NLS-1$
		html.append("\n"); //$NON-NLS-1$
		html.append(".button a {\n"); //$NON-NLS-1$
		html.append("display:block;\n"); //$NON-NLS-1$
		html.append("margin-left:2px;\n"); //$NON-NLS-1$
		html.append("margin-right:2px;\n"); //$NON-NLS-1$
		html.append("width:20px;\n"); //$NON-NLS-1$
		html.append("height:20px;\n"); //$NON-NLS-1$
		html.append("border:1px solid " + prefs.getToolbarBackground() + ";\n"); //$NON-NLS-1$ //$NON-NLS-2$
		html.append("writing-mode:tb-rl;\n"); //$NON-NLS-1$
		html.append("vertical-align:middle;\n"); //$NON-NLS-1$
		html.append("}\n"); //$NON-NLS-1$
		html.append("\n"); //$NON-NLS-1$
		html.append(".button a:hover {\n"); //$NON-NLS-1$
		html.append("border-top:1px solid ButtonHighlight;\n"); //$NON-NLS-1$
		html.append("border-left" + ":1px solid ButtonHighlight;\n"); //$NON-NLS-1$ //$NON-NLS-2$
		html.append("border-right" + ":1px solid ButtonShadow;\n"); //$NON-NLS-1$ //$NON-NLS-2$
		html.append("border-bottom:1px solid ButtonShadow;\n"); //$NON-NLS-1$
		html.append("}\n"); //$NON-NLS-1$
		html.append("\n"); //$NON-NLS-1$
		html.append(".separator {\n"); //$NON-NLS-1$
		html.append("background-color: ThreeDShadow;\n"); //$NON-NLS-1$
		html.append("height:100%;\n"); //$NON-NLS-1$
		html.append("width: 1px;\n"); //$NON-NLS-1$
		html.append("border-top:2px solid " + prefs.getToolbarBackground() + ";\n"); //$NON-NLS-1$ //$NON-NLS-2$
		html.append("border-bottom:2px solid " + prefs.getToolbarBackground() + ";\n"); //$NON-NLS-1$ //$NON-NLS-2$
		html.append("border-left:3px solid " + prefs.getToolbarBackground() + ";\n"); //$NON-NLS-1$ //$NON-NLS-2$
		html.append("border-right:3px solid " + prefs.getToolbarBackground() + ";\n"); //$NON-NLS-1$ //$NON-NLS-2$
		html.append("\n"); //$NON-NLS-1$
		html.append("}\n"); //$NON-NLS-1$
		html.append("\n"); //$NON-NLS-1$
		html.append("#container {\n"); //$NON-NLS-1$
		html.append("border-bottom:1px solid ThreeDShadow;\n"); //$NON-NLS-1$
		html.append("\n"); //$NON-NLS-1$
		html.append("}\n"); //$NON-NLS-1$
		html.append("</style>\n"); //$NON-NLS-1$

		html.append("<script language=\"JavaScript\">\n"); //$NON-NLS-1$
		html.append("\n"); //$NON-NLS-1$
		
		ToolbarButton[] buttons = data.getButtons();
		for (int i=0; i<buttons.length; i++) {
			if (!buttons[i].isSeparator()) {
				html.append("var " + buttons[i].getName() + " = new Image();\n"); //$NON-NLS-1$ //$NON-NLS-2$
				html.append("\n"); //$NON-NLS-1$
				html.append(buttons[i].getName() + ".src = \"" + buttons[i].getOnImage() + "\";\n"); //$NON-NLS-1$ //$NON-NLS-2$
			}
		}
		html.append("</script>\n"); //$NON-NLS-1$
		
		String script = data.getScript();
		if(script != null && !script.equals("")) { //$NON-NLS-1$
			html.append("<script language=\"JavaScript\"  src=\"scripts/" + script + "\">\n"); //$NON-NLS-1$ //$NON-NLS-2$
			html.append("</script>\n"); //$NON-NLS-1$
		}
		
		html.append("</head>\n"); //$NON-NLS-1$
		html.append("<body>\n"); //$NON-NLS-1$
		
		html.append("<table id=\"container\" width=\"100%\" border=\"0\" cellspacing=\"0\" cellpadding=\"0\" height=\"100%\" style='padding-left:5px'>\n"); //$NON-NLS-1$
		html.append("<tr>\n"); //$NON-NLS-1$
		html.append("<td nowrap style=\"font: " + prefs.getToolbarFont() + "\" valign=\"middle\">\n"); //$NON-NLS-1$ //$NON-NLS-2$
		html.append("<div id=\"titleTextTableDiv\" style=\"overflow:hidden; height:22px;\"><table><tr><td nowrap style=\"font:" + prefs.getToolbarFont() + "\"><div id=\"titleText\" >&nbsp;" + data.getTitle() + "</div></td></tr></table>\n"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
		html.append("</div>\n"); //$NON-NLS-1$
		html.append("<div style=\"position:absolute; top:0px; right:0px;\">\n"); //$NON-NLS-1$
		html.append("<table width=\"100%\" border=\"0\" cellspacing=\"1\" cellpadding=\"0\" height=\"100%\">\n"); //$NON-NLS-1$
		html.append("<tr>\n"); //$NON-NLS-1$
		html.append("<td align=\"right\">\n"); //$NON-NLS-1$
		html.append("<table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" height=\"100%\" style=\"background:" + prefs.getToolbarBackground() + "\">\n"); //$NON-NLS-1$ //$NON-NLS-2$
		html.append("<tr>\n"); //$NON-NLS-1$
		for (int i=0; i<buttons.length; i++) {
			if (buttons[i].isSeparator()) {
				html.append("<td align=\"middle\" class=\"separator\" valign=\"middle\">\n"); //$NON-NLS-1$
				html.append("</td>\n"); //$NON-NLS-1$
			} else {
				String btnOnString = buttons[i].isOn()? "buttonOn":"button";  //$NON-NLS-1$ //$NON-NLS-2$
				html.append("<td align=\"middle\" id=\"tdb_" + buttons[i].getName() + "\" class=\"" + btnOnString + "\" height=18>\n"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
				html.append("<a href=\"javascript:" + buttons[i].getAction() + "('b" + i + "','" + buttons[i].getActionArg() + "');\"\n"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$
				html.append("onmouseover=\"window.status='" + buttons[i].getTooltip() + "';return true;\"\n"); //$NON-NLS-1$ //$NON-NLS-2$
				html.append("onmouseout=\"window.status='';\"\n"); //$NON-NLS-1$
				html.append("id=\"b" + i + "\">\n"); //$NON-NLS-1$ //$NON-NLS-2$
				html.append("<img src=\"" + buttons[i].getOnImage() + "\"\n"); //$NON-NLS-1$ //$NON-NLS-2$
				html.append("alt='" + buttons[i].getTooltip() + "'\n"); //$NON-NLS-1$ //$NON-NLS-2$
				html.append("title='" + buttons[i].getTooltip() + "'\n"); //$NON-NLS-1$ //$NON-NLS-2$
				html.append("border=\"0\"\n"); //$NON-NLS-1$
				html.append("id=\"" + buttons[i].getName() + "\">\n"); //$NON-NLS-1$ //$NON-NLS-2$
				html.append("</a>\n"); //$NON-NLS-1$
				html.append("</td>\n"); //$NON-NLS-1$
			}
		}
		html.append("  </tr>\n"); //$NON-NLS-1$
		html.append("  </table>\n"); //$NON-NLS-1$
		html.append("  </td>\n"); //$NON-NLS-1$
		html.append("  </tr>\n"); //$NON-NLS-1$
		html.append("  </table>\n"); //$NON-NLS-1$
		html.append("  </div>\n"); //$NON-NLS-1$
		html.append("  </td>\n"); //$NON-NLS-1$
		html.append("  </tr>\n"); //$NON-NLS-1$
		html.append("</table>\n"); //$NON-NLS-1$
		html.append("</body>\n"); //$NON-NLS-1$
		html.append("</html>\n"); //$NON-NLS-1$
		String htmlString = html.toString();
		resp.getWriter().println(htmlString);
	}
}
